@@ -22,7 +22,7 @@ from gettext import gettext as _
 import gi
 gi.require_version("Gtk", "3.0")
 from gi.repository import GdkPixbuf, Gio, Gtk
-from softwareproperties.gtk.utils import current_distro, is_dark_theme
+from softwareproperties.gtk.utils import current_distro
 
 from .DialogUaAttach import DialogUaAttach
 from .DialogUaDetach import DialogUaDetach
@@ -50,25 +50,13 @@ class UbuntuProPage(object):
         self.switch_ua_esm_infra = parent.switch_ua_esm_infra
         self.label_ua_esm_infra = parent.label_ua_esm_infra
         self.label_ua_esm_infra_error = parent.label_ua_esm_infra_error
-        self.label_ua_esm_infra_error_messages = {
-            "enable": _("Could not enable ESM Infra. Please try again."),
-            "disable": _("Could not disable ESM Infra. Please try again."),
-        }
         self.switch_ua_esm_apps = parent.switch_ua_esm_apps
         self.label_ua_esm_apps = parent.label_ua_esm_apps
         self.label_ua_esm_apps_error = parent.label_ua_esm_apps_error
-        self.label_ua_esm_apps_error_messages = {
-            "enable": _("Could not enable ESM Apps. Please try again."),
-            "disable": _("Could not disable ESM Apps. Please try again."),
-        }
         self.switch_ua_livepatch = parent.switch_ua_livepatch
         self.checkbutton_livepatch_topbar = parent.checkbutton_livepatch_topbar
         self.label_ua_livepatch = parent.label_ua_livepatch
         self.label_ua_livepatch_error = parent.label_ua_livepatch_error
-        self.label_ua_livepatch_error_messages = {
-            "enable": _("Could not enable Livepatch. Please try again."),
-            "disable": _("Could not disable Livepatch. Please try again."),
-        }
         self.button_ua_fips = parent.button_ua_fips
         self.label_ua_fips_status = parent.label_ua_fips_status
         self.label_ua_fips_description = parent.label_ua_fips_description
@@ -77,12 +65,12 @@ class UbuntuProPage(object):
         self.label_ua_usg_status = parent.label_ua_usg_status
         self.label_ua_usg_description = parent.label_ua_usg_description
 
-        if is_dark_theme(self.stack_ua_attach):
-            ubuntu_pro_logo = GdkPixbuf.Pixbuf.new_from_file_at_scale(os.path.join(parent.datadir, 'ubuntu-pro-logo-dark.svg'), -1, 50, True)
-        else:
-            ubuntu_pro_logo = GdkPixbuf.Pixbuf.new_from_file_at_scale(os.path.join(parent.datadir, 'ubuntu-pro-logo.svg'), -1, 50, True)
+        ubuntu_pro_logo = GdkPixbuf.Pixbuf.new_from_file_at_scale(os.path.join(parent.datadir, 'ubuntu-pro-logo.svg'), -1, 50, True)
         parent.image_ubuntu_pro_logo.set_from_pixbuf(ubuntu_pro_logo)
 
+        # Display the tab on init which is only on LTS series
+        self.stack_ua_main.set_visible(True)
+
         parent.button_ua_attach.connect('clicked', self.on_button_ua_attach_clicked)
         parent.button_ua_detach.connect('clicked', self.on_button_ua_detach_clicked)
         self.on_ua_esm_infra_changed_handler = self.switch_ua_esm_infra.connect('notify::active', self.on_ua_esm_infra_changed)
@@ -222,7 +210,7 @@ class UbuntuProPage(object):
         dialog = DialogUaDetach(self._parent.window_main, self._parent.datadir, self.ua_object)
         dialog.run()
 
-    def set_service_enabled(self, service_name, enabled, error_label, error_label_messages):
+    def set_service_enabled(self, service_name, enabled, error_label):
         if error_label is not None:
             error_label.set_visible(False)
         service = self.get_service(service_name)
@@ -232,13 +220,11 @@ class UbuntuProPage(object):
             service.request_in_progress = False
             self.update_status()
         def on_error(error):
+            # FIXME
             print(error)
             if error_label is not None:
                 error_label.set_visible(True)
-                if enabled:
-                    error_label.set_label(error_label_messages["enable"])
-                else:
-                    error_label.set_label(error_label_messages["disable"])
+                error_label.label = error
             service.request_in_progress = False
             self.update_status()
         if enabled:
@@ -249,13 +235,13 @@ class UbuntuProPage(object):
         self.update_status()
 
     def on_ua_esm_infra_changed(self, switch, param):
-        self.set_service_enabled('esm-infra', self.switch_ua_esm_infra.get_active(), self.label_ua_esm_infra_error, self.label_ua_esm_infra_error_messages)
+        self.set_service_enabled('esm-infra', self.switch_ua_esm_infra.get_active(), self.label_ua_esm_infra_error)
 
     def on_ua_esm_apps_changed(self, switch, param):
-        self.set_service_enabled('esm-apps', self.switch_ua_esm_apps.get_active(), self.label_ua_esm_apps_error, self.label_ua_esm_apps_error_messages)
+        self.set_service_enabled('esm-apps', self.switch_ua_esm_apps.get_active(), self.label_ua_esm_apps_error)
 
     def on_ua_livepatch_changed(self, switch, param):
-        self.set_service_enabled('livepatch', self.switch_ua_livepatch.get_active(), self.label_ua_livepatch_error, self.label_ua_livepatch_error_messages)
+        self.set_service_enabled('livepatch', self.switch_ua_livepatch.get_active(), self.label_ua_livepatch_error)
 
     def on_checkbutton_livepatch_topbar_toggled(self, button):
         self.update_notifier_settings.handler_block(self.on_update_notifier_settings_changed_handler)
@@ -285,12 +271,12 @@ class UbuntuProPage(object):
         if result != Gtk.ResponseType.OK:
             return
 
-        self.set_service_enabled(service_name, True, None, None)
+        self.set_service_enabled(service_name, True, None)
 
     def on_button_ua_usg_clicked(self, button):
         service = self.get_service('usg')
         is_enabled = service is not None and service.status == 'enabled'
-        self.set_service_enabled('usg', not is_enabled, None, None)
+        self.set_service_enabled('usg', not is_enabled, None)
 
     def on_compliance_and_hardening_expand_changed(self, widget, param):
         self._parent.window_main.resize(1, 1)
